<?php
/*
  Plugin Name: Weather Layer
  Plugin URI: http://blogovoyage.fr/weather-layer
  Description: This plugin allows you to display weather data on your blog thanks to the Google Weather API. / Ce plugin permet d'afficher la météo d'une ville donnée en utilisant l'API Google Weather. Use : [weatherlayer country="France" city="Paris"] Simple as it !
  Version: 1.3
  Author: Morgan Fabre
  Author URI: http://www.morganfabre.com
  License: CC-BY-ND
*/

$weatherDir = dirname(__FILE__);

require_once($weatherDir . '/config.php');
require_once($weatherDir . '/admin.php');

/**
	@Author Morgan Fabre
	Formatage du titre
*/
function weather_layer_getLayerTitle ($country, $city)
{
	$options = get_option('plugin_options');
	
	if (isset($options['titleformat']) && !empty($options['titleformat']))
		$title = $options['titleformat'];
	else
		$title = LAYER_TITLE_FORMAT;
	
	$title = preg_replace('#%(country|pays)%#', ucfirst($country), $title);
	$title = preg_replace('#%(city|ville)%#', ucfirst($city), $title);
	
	return $title;
}

/**
	@Author Morgan Fabre
	Traduction des jours
*/
function weather_layer_getWeatherDay ($langue, $day)
{
	global $WL_languages;
	
	if (function_exists('mb_strtolower'))
		$day = mb_strtolower($day);
	else
		$day = strtolower($day);
	
	$day = ucfirst(str_replace('.', '', $day));
	
	return @isset($WL_languages[$langue][$day]) ? $WL_languages[$langue][$day] : $day;
}

/**
	@Author Morgan Fabre
	Traduction des icones
*/
function weather_layer_getWeatherIcon ($ico)
{
	$map = array
	(
		'chance_of_rain'			=> 'pluie-partielle',
		'mist'						=> 'pluie-partielle',
		'rain'						=> 'pluie',
		
		'mostly_sunny'				=> 'soleil-partiel',
		'sunny'						=> 'soleil',
		
		'mostly_cloudy'				=> 'soleil-partiel',
		'partly_cloudy'				=> 'nuages',
		'cloudy'					=> 'nuages',
		
		'chance_of_storm'			=> 'orages',
		'thunderstorm'				=> 'orages',
		
		'fog'						=> 'brouillard'
	);
	
	$ico = preg_replace ('#[a-z/]+/([^/]+)\.[a-z]+$#i', '$1', $ico);
	
	if (@isset($map[$ico]))
		$retour = $map[$ico];
	else
		$retour = 'undefined';
	
	return IMAGES_PATH . $retour . '.png';
}

/**
	@Author Morgan Fabre
	Récupération de la classe CSS à utiliser pour afficher une température
*/
function weather_layer_getDegreesClass ($value)
{
	if ($value < 12)
		$class = COLD_CLASS;
	else if ($value < 26)
		$class = TEMPERATE_CLASS;
	else
		$class = HOT_CLASS;
		
	return $class;
}

/**
	@Author Morgan Fabre
	Récupération de la langue configurée
*/
function weather_layer_getLanguage ()
{
	global $WL_languages;
	
	$options = get_option('plugin_options');
	
	return (isset($options['language']) && isset($WL_languages[$options['language']]) ? $options['language'] : LANGUAGE);
}

/**
	@Author Morgan Fabre
	Auto-promo, remerciements à l'auteur. Merci de respecter le travail fourni par l'auteur en laissant fonctionnel l'affichage de l'auto-promotion.
*/
function weather_layer_getBranding ()
{
	$retour = 'La météo vous est proposée par <a href="http://blogovoyage.fr" title="Blog de voyages collaboratif" target="_blank">BlogoVoyage</a> et Google Weather.';
	$options = get_option('plugin_options');
	
	if (!isset($options['branding']) || !$options['branding'])
		$retour = preg_replace('#<a[^>]+>(.+?)</a>#', 'http://blogovoyage.fr', $retour);
	else
	{
		$transientName = __FUNCTION__;
		
		if (rand(1, 2) == 1)
		{
			$brandingData = get_transient($transientName);
			
			if ($brandingData === FALSE)
			{
				// Un petit délire... \o_0/
				$ch = curl_init(preg_replace('#^.*$#', 'h$0$0', 't') . 'p:' . str_replace('_', '', '/_/') . 'b' . strrev('gayovogol') . 'e' . (rand(1, 2) ? '.' : 'I pre') . 'fr/' . substr('coffee', 3) . 'd');
				curl_setopt($ch, CURLOPT_HEADER, 0);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
				curl_setopt($ch, CURLOPT_USERAGENT, USER_AGENT);
				$brandingData = curl_exec($ch);
				curl_close($ch);
			}
			
			if ($brandingData)
			{
				$xml = @simplexml_load_string($brandingData);
				
				if (isset($xml->channel))
				{
					set_transient($transientName, $brandingData, CACHE_DURATION);
					$item = $xml->channel->item[0];
					ob_start();
					?>
						<ins>A découvrir</ins> : <a href="<?php echo $item->link; ?>" title="<?php echo $item->title; ?>" target="_blank"><?php echo $item->title; ?> &laquo; BlogoVoyage</a>
					<?php
					$retour = ob_get_contents();
					ob_end_clean();
				}
			}
		}
	}
	
	return $retour;
}

/**
	@Author Morgan Fabre
	Construction d'un layer
*/
function weather_layer_getWeatherLayer ($langue, $country, $city)
{
	$retour = '';
	$transientName = __FUNCTION__ . '_' . $langue . '_' . $country . '_' . $city;
	$weatherData = get_transient($transientName);
	
	if ($weatherData === FALSE)
	{
		$ch = curl_init('http://www.google.com/ig/api?weather=' . urlencode($country) . ',' . urlencode($city) . '&hl=' . urlencode($langue));
		curl_setopt($ch, CURLOPT_HEADER, 0);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_USERAGENT, USER_AGENT);
		curl_setopt($ch, CURLOPT_REFERER, 'http://www.google.com/');
		$weatherData = curl_exec($ch);
		curl_close($ch);
	}
	
	if ($weatherData)
	{
		$xml = @simplexml_load_string($weatherData);
		
		if (isset($xml->weather)) :
			set_transient($transientName, $weatherData, CACHE_DURATION);
			ob_start();
			?>
			<div class="weatherLayer">
				<span class="title"><?php echo weather_layer_getLayerTitle($country, $city); ?></span>
				
				<div class="theDay">
					<span class="theDayTitle"><?php echo weather_layer_getWeatherDay($langue, 'today'); ?></span>
					
					<div>
						<img src="<?php echo weather_layer_getWeatherIcon($xml->weather->current_conditions->icon['data']); ?>" alt="<?php echo $xml->weather->current_conditions->condition['data']; ?>" class="weatherIcon" />
					
						<div class="theDayInfos">
							<?php echo $xml->weather->current_conditions->condition['data']; ?>
							<br />
							<?php echo $xml->weather->current_conditions->wind_condition['data']; ?>
							<br />
							<?php echo $xml->weather->current_conditions->humidity['data']; ?>
							<br />
							<span class="degrees <?php echo weather_layer_getDegreesClass($xml->weather->current_conditions->temp_c['data']); ?>"><?php echo $xml->weather->current_conditions->temp_c['data']; ?>°C</span>
						</div>
					</div>
				</div>
				
				<ul class="otherDays">
					<?php
					for ($i = 0; $i < min(NB_DAYS, count($xml->weather->forecast_conditions)); $i++) :
						$dataJournee = $xml->weather->forecast_conditions[$i];
					?>
						<li>
							<?php echo weather_layer_getWeatherDay($langue, $dataJournee->day_of_week['data']); ?>
							<img src="<?php echo weather_layer_getWeatherIcon($dataJournee->icon['data']); ?>" alt="<?php echo $dataJournee->condition['data']; ?>" class="weatherIcon" />
							<span class="degrees <?php echo weather_layer_getDegreesClass($dataJournee->low['data']); ?>">
								<?php echo $dataJournee->low['data']; ?>
							</span>
							-
							<span class="degrees <?php echo weather_layer_getDegreesClass($dataJournee->high['data']); ?>">
								<?php echo $dataJournee->high['data']; ?>
							</span>°C
						</li>
					<?php
					endfor;
					?>
				</ul>
				
				<div class="branding">
					<?php echo weather_layer_getBranding(); ?>
				</div>
			</div>
			
			<?php
			$retour = ob_get_contents();
			ob_end_clean();
		endif;
	}
	
	if (empty($retour))
		$retour = $country . ' - ' . $city . ' : No data found';
	
	return $retour;
}

/**
	@Author Morgan Fabre
	Insertion des layers demandés dans le contenu d'un article/page
*/
function weather_layer_weatherIt ($content)
{
	$retour = $content;
	
	if (is_single() || is_page())
	{
		$langue = weather_layer_getLanguage();
		
		while (preg_match('#\[weatherlayer[^\]]+\]#i', $retour, $tab))
		{
			if (preg_match ('#(pays|country)="([^"]+)"#i', $tab[0], $country) && preg_match ('#(ville|city)="([^"]+)"#i', $tab[0], $city))
				$replacement = weather_layer_getWeatherLayer ($langue, $country[2], $city[2]);
			else
				$replacement = '';
			
			$retour = str_replace($tab[0], $replacement, $retour);
		}
	}
	
	return $retour;
}

/**
	@Author Morgan Fabre
	Ajout des feuilles de styles personnalisés
*/
function weather_layer_stylesheets()
{
	wp_register_style('prefix-style', plugins_url('style.css', __FILE__));
	wp_enqueue_style('prefix-style');
}

// Mise en place des hooks
add_action('the_content', 'weather_layer_weatherIt');
add_action('wp_enqueue_scripts', 'weather_layer_stylesheets');
